@@ -1,5 +1,4 @@
-"""
-Trackmania.io API Wrapper
+"""Trackmania.io API Wrapper
 ~~~~~~~~~~~~~~~~~~~~~~~~~
 
 A wrapper for Trackmania.io api service.
@@ -15,6 +14,7 @@ from .config import *
 from .constants import *
 from .errors import *
 from .structures.ad import *
+from .structures.cotd import *
 from .structures.map import *
 from .structures.medal_times import *
 from .structures.player import *
