@@ -1,26 +1,3 @@
-"""
-MIT License
-
-Copyright (c) 2022-present Deepesh Nimma
-
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
-"""
 import json
 from contextlib import suppress
 from typing import Dict, List, Tuple
@@ -39,22 +16,31 @@ async def get_player(
     player_id: str, raw: bool = False
 ) -> Player | Tuple[Player, Dict] | None:
     """
-    Retrieves a player's information using their player_id
+    Retrieves a player's information using their player_id.
 
-    :param player_id: The player id to get information for.
-    :type player_id: str
-    :param raw: Whether to return the raw data from the API.
-    :type raw: bool
-    :raises :class:`InvalidIDError`: if the player id is empty, or no player exists with that player_id.
-    :return: The player's information
-    :rtype: :class:`Player` | :class:`Tuple`[:class:`Player`, :class:`Dict`] | None
+    Parameters
+    ----------
+    player_id : str
+        The player_id to get the information for.
+    raw : bool, optional
+        Whether to return the raw data from the API alongside the parsed one, by default False
 
-    Caching
-    * Caches the player information for 10 minutes.
-    * Caches `username:player_id` pair forever.
-    * Caches `player_id:username` pair forever.
+    Returns
+    -------
+    :class:`Player` | :class:`Tuple[Player, Dict]` | None
+        The player's information.
+
+    Raises
+    ------
+    `InvalidIDError`
+        If the player_id is empty, or no player exists with that player_id.
     """
-    cache_client = redis.Redis(host=Client.redis_host, port=Client.redis_port)
+    cache_client = redis.Redis(
+        host=Client.REDIS_HOST,
+        port=Client.REDIS_PORT,
+        db=Client.REDIS_DB,
+        password=Client.REDIS_PASSWORD,
+    )
 
     if player_id == "":
         raise InvalidIDError("The player id cannot be empty.")
@@ -71,7 +57,7 @@ async def get_player(
             if raw:
                 return player, json.loads(cache_client.get(f"{player_id}|data"))
     api_client = APIClient()
-    player_resp = await api_client.get(TMIO.build([TMIO.tabs.player, player_id]))
+    player_resp = await api_client.get(TMIO.build([TMIO.TABS.PLAYER, player_id]))
     await api_client.close()
 
     player_data = player_parsers.parse_player(player_resp)
@@ -91,22 +77,29 @@ async def search_player(
     username: str,
 ) -> None | PlayerSearchResult | List[PlayerSearchResult]:
     """
-    Searches for a player's information
+    Searches for a player's information using their username.
 
-    :param username: The player's username to search for.
-    :type username: str
-    :raises :class:`InvalidUsernameError`: If the username is empty or if there is no users with this username.
-    :return: None if no players. :class:`PlayerSearchResult` if one player. List of :class:`PlayerSearchResult` if multiple players.
-    :rtype: None|:class:`PlayerSearchResult`|:class:`List`[:class:`PlayerSearchResult`]
+    Parameters
+    ----------
+    username : str
+        The player's username to search for.
+
+    Returns
+    -------
+    None | :class:`PlayerSearchResult` | :class:`List[PlayerSearchResult]`
+        None if no players. `PlayerSearchResult` if only one player. `List`[`PlayerSearchResult`] if multiple players.
+
+    Raises
+    ------
+    `InvalidUsernameError`
+        if the username is empty.
     """
-    cache_client = redis.Redis(host=Client.redis_host, port=Client.redis_port)
-
     if username == "":
         raise InvalidUsernameError("Usernmae cannot be empty.")
 
     api_client = APIClient()
     search_result = await api_client.get(
-        TMIO.build([TMIO.tabs.players]) + f"/find?search={username}"
+        TMIO.build([TMIO.TABS.PLAYERS]) + f"/find?search={username}"
     )
     await api_client.close()
 
@@ -133,19 +126,24 @@ async def search_player(
 
 async def to_account_id(username: str) -> str | None:
     """
-    Returns the account id of the given username
+    Returns the account id of the given username.
 
-    :param username: The username of the player.
-    :type username: str
-    :return: The id of the player.
-    :rtype: str | None
+    Parameters
+    ----------
+    username : str
+        The username of the player.
 
-    Caching
-
-    * Caches `username:player_id` pair forever.
-    * Caches `player_id:username` pair forever.
+    Returns
+    -------
+    str | None
+        The id of the player.
     """
-    cache_client = redis.Redis(host=Client.redis_host, port=Client.redis_port)
+    cache_client = redis.Redis(
+        host=Client.REDIS_HOST,
+        port=Client.REDIS_PORT,
+        db=Client.REDIS_DB,
+        password=Client.REDIS_PASSWORD,
+    )
 
     with suppress(ConnectionRefusedError, redis.exceptions.ConnectionError):
         if cache_client.exists(f"{username.lower()}|id"):
@@ -174,12 +172,22 @@ async def to_username(player_id: str) -> str | None:
     """
     Gets a player's username from their ID.
 
-    :param player_id: The ID of the player.
-    :type player_id: str
-    :return: The player's username, None if the player does not exist.
-    :rtype: str | None
+    Parameters
+    ----------
+    player_id : str
+        The ID of the player.
+
+    Returns
+    -------
+    str | None
+        The username of the player. `None` if the player doesn't exist.
     """
-    cache_client = redis.Redis(host=Client.redis_host, port=Client.redis_port)
+    cache_client = redis.Redis(
+        host=Client.REDIS_HOST,
+        port=Client.REDIS_PORT,
+        db=Client.REDIS_DB,
+        password=Client.REDIS_PASSWORD,
+    )
 
     with suppress(ConnectionRefusedError, redis.exceptions.ConnectionError):
         if cache_client.exists(f"{player_id}|username"):
@@ -195,23 +203,38 @@ async def to_username(player_id: str) -> str | None:
     return None
 
 
-async def top_matchmaking(group: int, page: int = 0):
+async def top_matchmaking(group: int, page: int = 0) -> Dict:
     """
-    Retrieves the Matchmaking leaderboard.
+    Retrieves the
 
-    :param group: The group id, 2 is 3v3 matchmaking and 3 is royal matchmaking.
-    :type group: int
-    :param page: The page of the leaderboard. Each number is 50 users, defaults to 0
-    :type page: int, optional
+    Parameters
+    ----------
+    group : int
+        The group id. 2 for 3v3 matchmaking and 3 for royal.
+    page : int, optional
+        The page of the leaderboard. Each page has 50 players. by default 0
 
-    Caching
+    Returns
+    -------
+    :class:`Dict`
+        The matchmaking data.
 
-    Caches each page for 1 hour.
+    Raises
+    ------
+    `InvalidMatchmakingGroupError`
+        If the group is not 2 or 3.
     """
-    cache_client = redis.Redis(host=Client.redis_host, port=Client.redis_port)
+    cache_client = redis.Redis(
+        host=Client.REDIS_HOST,
+        port=Client.REDIS_PORT,
+        db=Client.REDIS_DB,
+        password=Client.REDIS_PASSWORD,
+    )
 
     if int(group) not in (2, 3):
         raise InvalidMatchmakingGroupError("Matchmaking group should be 2 or 3.")
+    if page < 0:
+        raise ValueError("Page must be greater than or equal to 0.")
 
     with suppress(ConnectionRefusedError, redis.exceptions.ConnectionError):
         if cache_client.exists(f"matchmaking|{group}|{page}"):
@@ -219,7 +242,7 @@ async def top_matchmaking(group: int, page: int = 0):
 
     api_client = APIClient()
     matchmaking_resp = await api_client.get(
-        TMIO.build([TMIO.tabs.top_matchmaking, group, page])
+        TMIO.build([TMIO.TABS.TOP_MATCHMAKING, group, page])
     )
     await api_client.close()
 
@@ -231,25 +254,36 @@ async def top_matchmaking(group: int, page: int = 0):
     return matchmaking_resp
 
 
-async def top_trophies(page: int = 0):
+async def top_trophies(page: int = 0) -> Dict:
     """
-    Gets the Trophy leaderboard.
+    Gets the trophy leaderboard.
 
-    :param page: Page for the leaderboard, each page contains 50 players. defaults to 0
-    :type page: int, optional
+    Parameters
+    ----------
+    page : int, optional
+        Page for the leaderboard, each page contains 50 players. by default 0
 
-    Caching
-
-    Caches trophy leaderboard page for 3 hr
+    Returns
+    -------
+    :class:`Dict`
+        The trophy leaderboard data.
     """
-    cache_client = redis.Redis(host=Client.redis_host, port=Client.redis_port)
+    if page < 0:
+        raise ValueError("Page cannot be less than 0.")
+
+    cache_client = redis.Redis(
+        host=Client.REDIS_HOST,
+        port=Client.REDIS_PORT,
+        db=Client.REDIS_DB,
+        password=Client.REDIS_PASSWORD,
+    )
 
     with suppress(ConnectionRefusedError, redis.exceptions.ConnectionError):
         if cache_client.exists(f"trophies|{page}"):
             return json.loads(cache_client.get(f"trophies|{page}"))
 
     api_client = APIClient()
-    trophies_resp = await api_client.get(TMIO.build([TMIO.tabs.top_trophies, page]))
+    trophies_resp = await api_client.get(TMIO.build([TMIO.TABS.TOP_TROPHIES, page]))
     await api_client.close()
 
     with suppress(ConnectionRefusedError, redis.exceptions.ConnectionError):
